@@ -84,7 +84,7 @@
 #define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOMPLETION_NO_DEPRECATED
-#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
 #endif
 #ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
 #  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x57300
 #  endif
 #endif
 
